# eric7.WebBrowser.CookieJar.CookiesConfigurationDialog

Module implementing the cookies configuration dialog.

### Global Attributes

None

### Classes

CookiesConfigurationDialog | Class implementing the cookies configuration dialog.

### Functions

None

## CookiesConfigurationDialog

Class implementing the cookies configuration dialog.

### Derived from

QDialog, Ui_CookiesConfigurationDialog

### Class Attributes

None

### Class Methods

None

### Methods

CookiesConfigurationDialog | Constructor
accept | Public slot to accept the dialog.
on_cookiesButton_clicked | Private slot to show the cookies dialog.
on_exceptionsButton_clicked | Private slot to show the cookies exceptions dialog.

### Static Methods

None

#### CookiesConfigurationDialog (Constructor)

CookiesConfigurationDialog(parent)

Constructor

parent (QWidget)
  reference to the parent object

#### CookiesConfigurationDialog.accept

accept()

Public slot to accept the dialog.

#### CookiesConfigurationDialog.on_cookiesButton_clicked

on_cookiesButton_clicked()

Private slot to show the cookies dialog.

#### CookiesConfigurationDialog.on_exceptionsButton_clicked

on_exceptionsButton_clicked()

Private slot to show the cookies exceptions dialog.

Up